@@ -1,6 +1,10 @@
 # Function to permute arrays of non-atomic elements (e.g. POSIXct)
 .aperm2 <- function(x, new_order) {
   old_dims <- dim(x)
+  attr_bk <- attributes(x)
+  if ('dim' %in% names(attr_bk)) {
+    attr_bk[['dim']] <- NULL
+  }
   if (is.numeric(x)) {
     x <- aperm(x, new_order)
   } else {
@@ -9,5 +13,6 @@
     x <- x[as.vector(y)]
   }
   dim(x) <- old_dims[new_order]
+  attributes(x) <- c(attributes(x), attr_bk)
   x
 }
